@@ -225,7 +225,6 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
   else if (talgn %in% c("center", "centre"))
     ta <- "\\trqc"
 
-  
   if (length(ttllst) > 0) {
     
     for (ttls in ttllst) {
@@ -285,8 +284,10 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
                                    length(ttls$titles) + alcnt + blcnt, 
                                    1, ttls$borders)
             
+            sm <- get_spacing_multiplier(rs$font_size)
+            
             bl <- paste0("\\trowd\\trgaph0", ta, tb, "\\cellx", w, 
-                         algn, "\\cell\\row\n")
+                         algn, sm, "\\cell\\row\n")
             cnt <- cnt + 1
           }
           
@@ -301,11 +302,25 @@ get_titles_rtf <- function(ttllst, content_width, rs, talgn = "center") {
         # Split title strings if they exceed width
         tmp <- split_string_rtf(ttls$titles[[i]], width, rs$units)
         
+        fz <- ""
+        fs <- ""
+        if (!is.null(ttls$font_size)) {
+          
+          fz <- paste0("\\fs", ttls$font_size * 2, 
+                       get_spacing_multiplier(ttls$font_size)) 
+          fs <- paste0("\\fs", rs$font_size * 2)
+        }
+        
+        
+        tb <- tmp$rtf
+        if (ttls$bold)
+          tb <- paste0("\\b ", tmp$rtf, "\\b0")
+        
         # Concatenate title string
         if (al != "")
           ret <- append(ret, al)
         ret <- append(ret, paste0("\\trowd\\trgaph0", ta, b, "\\cellx", w, 
-                                  algn, " ", tmp$rtf, "\\cell\\row\n"))
+                                  algn, fz, " ", tb, fs, "\\cell\\row\n"))
         if (bl != "")
           ret <- append(ret, bl)
 
@@ -678,7 +693,7 @@ get_page_by_rtf <- function(pgby, width, value, rs, talgn) {
 # Utilities ---------------------------------------------------------------
 
 
-get_cell_borders <- function(row, col, nrow, ncol, brdrs, flag = "") {
+get_cell_borders <- function(row, col, nrow, ncol, brdrs, flag = "", exclude = NULL) {
   
   t <- ""
   b <- ""
@@ -740,6 +755,17 @@ get_cell_borders <- function(row, col, nrow, ncol, brdrs, flag = "") {
     }
   }
   
+  if (!is.null(exclude)) {
+    if (any(exclude == "top"))
+      t <- ""
+    if (any(exclude == "bottom"))
+      b <- ""
+    if (any(exclude == "left"))
+      l <- ""
+    if (any(exclude == "right"))
+      r <- ""
+  }
+  
   ret <- paste0(t, b, l, r)
   
   return(ret)
