@@ -977,30 +977,36 @@ test_that("rtf2-28: Plot with page by on report works as expected.", {
 
 test_that("rtf2-29: Simplest RTF Plot with valign top works as expected.", {
   
-  library(ggplot2)
+  if (dev) {
+    library(ggplot2)
+    
+    fp <- file.path(base_path, "rtf2/test29.rtf")
+    
+    p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+    
+    plt <- create_plot(p, height = 4, width = 8)
+    
+    
+    rpt <- create_report(fp, output_type = "RTF", font = fnt, font_size = fsz) %>%
+      page_header("Client", "Study: XYZ") %>%
+      titles("Figure 1.0", "MTCARS Miles per Cylinder Plot") %>%
+      set_margins(top = 1, bottom = 1) %>%
+      add_content(plt, align = "center") %>%
+      footnotes("* Motor Trend, 1974", valign = "top") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+    
+    
+    res <- write_report(rpt)
+    
+    #print(res)
+    
+    expect_equal(file.exists(fp), TRUE)
+    expect_equal(res$pages, 1)
   
-  fp <- file.path(base_path, "rtf2/test29.rtf")
-  
-  p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
-  
-  plt <- create_plot(p, height = 4, width = 8)
-  
-  
-  rpt <- create_report(fp, output_type = "RTF", font = fnt, font_size = fsz) %>%
-    page_header("Client", "Study: XYZ") %>%
-    titles("Figure 1.0", "MTCARS Miles per Cylinder Plot") %>%
-    set_margins(top = 1, bottom = 1) %>%
-    add_content(plt, align = "center") %>%
-    footnotes("* Motor Trend, 1974", valign = "top") %>%
-    page_footer("Time", "Confidential", "Page [pg] of [tpg]")
-  
-  
-  res <- write_report(rpt)
-  
-  #print(res)
-  
-  expect_equal(file.exists(fp), TRUE)
-  expect_equal(res$pages, 1)
+  } else {
+    
+   expect_equal(TRUE, TRUE) 
+  }
   
   
 })
@@ -1009,30 +1015,36 @@ test_that("rtf2-29: Simplest RTF Plot with valign top works as expected.", {
 
 test_that("rtf2-30: Simplest RTF Plot with valign bottom works as expected.", {
   
-  library(ggplot2)
+  if (dev) {
+    library(ggplot2)
+    
+    fp <- file.path(base_path, "rtf2/test30.rtf")
+    
+    p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
+    
+    plt <- create_plot(p, height = 4, width = 8) %>%
+      footnotes("* Motor Trend, 1974", valign = "bottom")
+    
+    
+    rpt <- create_report(fp, output_type = "RTF", font = fnt, font_size = fsz) %>%
+      page_header("Client", "Study: XYZ") %>%
+      titles("Figure 1.0", "MTCARS Miles per Cylinder Plot") %>%
+      set_margins(top = 1, bottom = 1) %>%
+      add_content(plt, align = "center") %>%
+      page_footer("Time", "Confidential", "Page [pg] of [tpg]")
+    
+    
+    res <- write_report(rpt)
+    
+    #print(res)
+    
+    expect_equal(file.exists(fp), TRUE)
+    expect_equal(res$pages, 1)
   
-  fp <- file.path(base_path, "rtf2/test30.rtf")
-  
-  p <- ggplot(mtcars, aes(x=cyl, y=mpg)) + geom_point()
-  
-  plt <- create_plot(p, height = 4, width = 8) %>%
-    footnotes("* Motor Trend, 1974", valign = "bottom")
-  
-  
-  rpt <- create_report(fp, output_type = "RTF", font = fnt, font_size = fsz) %>%
-    page_header("Client", "Study: XYZ") %>%
-    titles("Figure 1.0", "MTCARS Miles per Cylinder Plot") %>%
-    set_margins(top = 1, bottom = 1) %>%
-    add_content(plt, align = "center") %>%
-    page_footer("Time", "Confidential", "Page [pg] of [tpg]")
-  
-  
-  res <- write_report(rpt)
-  
-  #print(res)
-  
-  expect_equal(file.exists(fp), TRUE)
-  expect_equal(res$pages, 1)
+  } else {
+    
+    expect_equal(TRUE, TRUE) 
+  }
   
   
 })
@@ -1557,7 +1569,8 @@ test_that("rtf2-47: 9 pt font cm works as expected.", {
   
   rpt <- create_report(fp, output_type = "RTF", font_size = 9, 
                        font = "Courier",
-                       orientation = "portrait") %>%
+                       orientation = "portrait",
+                       units = "cm") %>%
     page_header("left", "right") %>%
     titles("IRIS Data Frame") %>%
     add_content(create_table(iris)) %>%
@@ -1601,7 +1614,8 @@ test_that("rtf2-49: 11 pt font cm works as expected.", {
   
   rpt <- create_report(fp, output_type = "RTF", font_size = 11, 
                        font = "Courier",
-                       orientation = "portrait") %>%
+                       orientation = "portrait", 
+                       units = "cm") %>%
     page_header("left", "right") %>%
     titles("IRIS Data Frame") %>%
     add_content(create_table(iris)) %>%
@@ -1749,7 +1763,7 @@ test_that("rtf2-user1: demo table works.", {
     block_fmt <- c(AGE = "Age", SEX = "Sex", RACE = "Race")
     
     # Define table
-    tbl <- create_table(demo, first_row_blank = TRUE) %>%
+    tbl <- create_table(demo, first_row_blank = TRUE, borders = c("outside")) %>%
       column_defaults(from = "ARM A", to = "ARM D", width = 1.25) %>% 
       define(var, blank_after = TRUE, dedupe = TRUE,
              format = block_fmt, label = "") %>%
